from pprint import pprint
import time

import logging
from googleapiclient import discovery

logging.basicConfig(level=logging.INFO)

project = 'yt-py-345518' 
zone = 'us-west4-a'
instance = 'py-gce'
service = discovery.build('compute', 'v1')

def get_status():
    request = service.instances().get(project=project, zone=zone, instance=instance)
    response = request.execute()
    return response['status']

def get_op_status(operation_name):
    request = service.zoneOperations().get(project=project, zone=zone, operation=operation_name)
    response = request.execute()
    return response['status']

def wait_on_operation(op_name):
    for i in range(20):
        status = get_op_status(op_name)
        logging.info("Operation status is %s", status)
        if status == 'DONE':
            return
        time.sleep(30)


def stop():
    request = service.instances().stop(project=project, zone=zone, instance=instance)
    response = request.execute()
    wait_on_operation(response['name'])


def start():
    request = service.instances().start(project=project, zone=zone, instance=instance)
    response = request.execute()
    wait_on_operation(response['name'])


if __name__ == "__main__":
    if get_status() != "RUNNING":
        logging.info("Instance is not running, skipping")
    else:
        logging.info("Stopping")
        stop()
        logging.info("Starting")
        start()
